@@ -213,41 +213,6 @@ class FaceCropper:
         print()
         print('OK faces / All images: %.2f%% ' % (self.m_ok_face / self.n_all * 100))
 
-def main():
-    parser = argparse.ArgumentParser()
-    parser.add_argument('input_dir', type=str)
-    parser.add_argument('output_dir', type=str)
-    parser.add_argument('resolution', type=int, help='crop resolution. If you set resolution = -1, you can skip resizing process.')
-    parser.add_argument('--mirror_padding', action='store_true', default=False, help='If you add this option, mirror padding is excecuted.')
-    args = parser.parse_args()
-
-    image_names = [f for f in os.listdir(args.input_dir) if f.endswith(('.png', '.jpg', '.jpeg', '.JPG'))]
-    if not os.path.exists(args.output_dir):
-        os.mkdir(args.output_dir)
-    face_cropper = FaceCropper(args.resolution, check_resolution=False, mirror_padding=args.mirror_padding, upper_limit_of_black_region_ratio=1.)
-
-    for image_name in image_names:
-        image_path = os.path.join(args.input_dir, image_name)
-        cropped_imgs = face_cropper.crop_face_from_path(image_path)
-        if cropped_imgs is None:
-            continue
-
-        for i_face, cropped_img in enumerate(cropped_imgs):
-            if cropped_img is not None:
-                output_img_path = os.path.join(args.output_dir, image_name[:-4] + '-%d.png' % i_face)
-                cropped_img.save(output_img_path)
-    face_cropper.summary()
-
-if __name__ == '__main__':
-    main()
-import os, argparse
-import numpy as np
-from PIL import Image, ImageFile
-from tqdm import tqdm
-import cv2
-from dlib import get_frontal_face_detector, shape_predictor
-from imutils import face_utils
-
 
 def calc_black_region_ratio(PIL_img):
     img_array = np.asarray(PIL_img)
@@ -439,29 +404,4 @@ class FaceCropper:
             cropped_imgs.append(cropped_img)
         return cropped_imgs
 
-    # def summary(self):
-    #     print('Resolution: %d' % self.resolution)
-    #     print('Upper limit of black region ratio %.0f%%' % (self.upper_limit_of_black_region_ratio * 100))
-    #     print()
-    #     print('All images: %d' % self.n_all)
-    #     print('Small images: %d(%.2f%%)' % (self.n_small, self.n_small / self.n_all * 100))
-    #     print('Detected images: %d(%.2f%%)' % (self.n_detected, self.n_detected / self.n_all * 100))
-    #     print('Not detected images: %d(%.2f%%)' % (self.n_not_detected, self.n_not_detected / self.n_all * 100))
-    #     print()
-    #     print('All faces: %d(%.2f%% for Detected images) ' % (self.m_all_face, self.m_all_face / self.n_detected * 100))
-    #     print('OK faces: %d(%.2f%%)' % (self.m_ok_face, self.m_ok_face / self.m_all_face * 100))
-    #     print('Low resolution faces: %d(%.2f%%)' % (self.m_low_resolution, self.m_low_resolution / self.m_all_face * 100))
-    #     print('High black region ratio faces: %d(%.2f%%)' % (self.m_high_black_region_ratio, self.m_high_black_region_ratio / self.m_all_face * 100))
-    #     print()
-    #     print('OK faces / All images: %.2f%% ' % (self.m_ok_face / self.n_all * 100))
 
-def crop_image(img, resolution, if_mirror_padding=False):
-    # img is pil or path
-    face_cropper = FaceCropper(resolution, check_resolution=False, mirror_padding=if_mirror_padding, upper_limit_of_black_region_ratio=1.)
-    cropped_img = face_cropper.crop_face(img)
-    return cropped_img
-
-def crop_image_from_path(img_path, resolution, if_mirror_padding=False):
-    face_cropper = FaceCropper(resolution, check_resolution=False, mirror_padding=if_mirror_padding, upper_limit_of_black_region_ratio=1.)
-    cropped_img = face_cropper.crop_face_from_path(img)
-    return cropped_img
\ No newline at end of file
